| Title: | Partially Residual Balanced Multi-Session Designs |
|---|---|
| Description: | Provides functions for generating novel partially residual balanced multi-session designs. These designs arrange products over sessions and periods under partial balance restrictions and compute canonical efficiency factors for direct and residual (carryover) effects. For general background on PRBMS and related crossover design literature, see Aggarwal and Jha (2006) <doi:10.1080/03610920600695824> and Fardos et al. (2023) <doi:10.18576/jsap/120227>. |
| Authors: | Boyina Devi Priyanka [aut, cre], Cini Varghese [ctb], Rajender Parsad [ctb], Mohd Harun [ctb], Anindita Datta [ctb], Vinaykumar L.N. [ctb] |
| Maintainer: | Boyina Devi Priyanka <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0.1 |
| Built: | 2026-06-01 09:28:04 UTC |
| Source: | https://github.com/cran/PRBMSdesigns |
This function generates a new series of PRBMS designs using initial sequence q1: [1, v, 2, v-1, ..., v/2, v/2+1] with parameters (v, s = v/2, m = 2, p = v), and calculates the canonical efficiency factors.
SERIES1(v, verbose = TRUE)SERIES1(v, verbose = TRUE)
v |
Total number of products |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES1(8, verbose = FALSE)SERIES1(8, verbose = FALSE)
This function generates a new series of PRBMS designs using initial sequence q1: [1, v, 2, v-1, ..., v/2, v/2+1] with parameters (v, s = 2, m = v/2, p = v), and calculates the canonical efficiency factors.
SERIES2(v, verbose = TRUE)SERIES2(v, verbose = TRUE)
v |
Total number of products |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES2(8, verbose = FALSE)SERIES2(8, verbose = FALSE)
This function generates a new series of PRBMS designs using initial sequence q1: [1, v, 2, v-1, ..., v/2, v/2+1] with parameters (v, s = 2, m = (v - 2)/2, p = v), and calculates the canonical efficiency factors.
SERIES3(v, verbose = TRUE)SERIES3(v, verbose = TRUE)
v |
Total number of products |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES3(8, verbose = FALSE)SERIES3(8, verbose = FALSE)
This function generates a new series of PRBMS designs using initial sequences q2: [1, v, 2, v-1, ..., (v+3)/2, (v+1)/2] or q3: [v, 1, v-1, 2, ..., (v-1)/2, (v+1)/2], with parameters (v, s = 2, m = (v - 1)/2, p = v), and calculates the canonical efficiency factors.
SERIES4(v, verbose = TRUE)SERIES4(v, verbose = TRUE)
v |
Total number of products |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES4(7, verbose = FALSE)SERIES4(7, verbose = FALSE)
This function generates a new series of PRBMS designs using initial sequences q2: [1, v, 2, v-1, ..., (v+3)/2, (v+1)/2] or q3: [v, 1, v-1, 2, ..., (v-1)/2, (v+1)/2], with parameters (v, s = 2, m = [(v - 1)/2, (v + 1)/2], p = v), and calculates the canonical efficiency factors.
SERIES5(v, verbose = TRUE)SERIES5(v, verbose = TRUE)
v |
Total number of products |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES5(7, verbose = FALSE)SERIES5(7, verbose = FALSE)
This function generates a new series of PRBMS designs using initial sequence q4: [x^0, x^1, x^2, ..., x^(v - 2)] with parameters (v, s = 2, m = (v - 1)/2, p = v), and calculates the canonical efficiency factors.
SERIES6(v, verbose = TRUE)SERIES6(v, verbose = TRUE)
v |
Total number of products |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES6(7, verbose = FALSE)SERIES6(7, verbose = FALSE)
This function generates a new series of PRBMS designs using the initial sequence q4': [x^0, x^1, x^2, ..., x^(v-2)] with parameters (v, s = 2, m = [(v - 1)/2, (v + 1)/2], p = v). It also computes the canonical efficiency factors
SERIES7(v, verbose = TRUE)SERIES7(v, verbose = TRUE)
v |
Total number of products (must be prime) |
verbose |
Logical; if TRUE, prints design layout and efficiency factors |
A list containing design and efficiency measures
SERIES7(7, verbose = FALSE)SERIES7(7, verbose = FALSE)