Title: Partially Residual Balanced Multi-Session Designs
Version: 1.0.1
Description: Provides functions for generating novel partially residual balanced multi-session designs. These designs arrange products over sessions and periods under partial balance restrictions and compute canonical efficiency factors for direct and residual (carryover) effects. For general background on PRBMS and related crossover design literature, see Aggarwal and Jha (2006) <doi:10.1080/03610920600695824> and Fardos et al. (2023) <doi:10.18576/jsap/120227>.
License: GPL-2
Encoding: UTF-8
Imports: MASS
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-29 08:58:27 UTC; admin
Author: Boyina Devi Priyanka [aut, cre], Cini Varghese [ctb], Rajender Parsad [ctb], Mohd Harun [ctb], Anindita Datta [ctb], Vinaykumar L.N. [ctb]
Maintainer: Boyina Devi Priyanka <boyinadevipriyanka@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-02 09:10:09 UTC

Series 1 PRBMS Design

Description

This function generates a new series of PRBMS designs using initial sequence q1: [1, v, 2, v-1, ..., v/2, v/2+1] with parameters (v, s = v/2, m = 2, p = v), and calculates the canonical efficiency factors.

Usage

SERIES1(v, verbose = TRUE)

Arguments

v

Total number of products

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES1(8, verbose = FALSE)


Series 2 PRBMS Design

Description

This function generates a new series of PRBMS designs using initial sequence q1: [1, v, 2, v-1, ..., v/2, v/2+1] with parameters (v, s = 2, m = v/2, p = v), and calculates the canonical efficiency factors.

Usage

SERIES2(v, verbose = TRUE)

Arguments

v

Total number of products

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES2(8, verbose = FALSE)


Series 3 PRBMS Design

Description

This function generates a new series of PRBMS designs using initial sequence q1: [1, v, 2, v-1, ..., v/2, v/2+1] with parameters (v, s = 2, m = (v - 2)/2, p = v), and calculates the canonical efficiency factors.

Usage

SERIES3(v, verbose = TRUE)

Arguments

v

Total number of products

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES3(8, verbose = FALSE)


Series 4 PRBMS Design

Description

This function generates a new series of PRBMS designs using initial sequences q2: [1, v, 2, v-1, ..., (v+3)/2, (v+1)/2] or q3: [v, 1, v-1, 2, ..., (v-1)/2, (v+1)/2], with parameters (v, s = 2, m = (v - 1)/2, p = v), and calculates the canonical efficiency factors.

Usage

SERIES4(v, verbose = TRUE)

Arguments

v

Total number of products

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES4(7, verbose = FALSE)


Series 5 PRBMS Design

Description

This function generates a new series of PRBMS designs using initial sequences q2: [1, v, 2, v-1, ..., (v+3)/2, (v+1)/2] or q3: [v, 1, v-1, 2, ..., (v-1)/2, (v+1)/2], with parameters (v, s = 2, m = [(v - 1)/2, (v + 1)/2], p = v), and calculates the canonical efficiency factors.

Usage

SERIES5(v, verbose = TRUE)

Arguments

v

Total number of products

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES5(7, verbose = FALSE)


Series 6 PRBMS Design

Description

This function generates a new series of PRBMS designs using initial sequence q4: [x^0, x^1, x^2, ..., x^(v - 2)] with parameters (v, s = 2, m = (v - 1)/2, p = v), and calculates the canonical efficiency factors.

Usage

SERIES6(v, verbose = TRUE)

Arguments

v

Total number of products

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES6(7, verbose = FALSE)


Series 7 PRBMSD Designs

Description

This function generates a new series of PRBMS designs using the initial sequence q4': [x^0, x^1, x^2, ..., x^(v-2)] with parameters (v, s = 2, m = [(v - 1)/2, (v + 1)/2], p = v). It also computes the canonical efficiency factors

Usage

SERIES7(v, verbose = TRUE)

Arguments

v

Total number of products (must be prime)

verbose

Logical; if TRUE, prints design layout and efficiency factors

Value

A list containing design and efficiency measures

Examples

SERIES7(7, verbose = FALSE)